
![Logo](https://i.ibb.co/80xDDsg/ETools-Logo.png)


# ETools 

ETools is an open-source python package that allows you to many things with ease, using command prompt.


### Authors

- [**Wyatt Johnson**](https://github.com/realendie)


### Features

- Ability to download any YouTube video free of charge.
- Ability to convert files to most standard file types.

### Installation

To install ETools YouTube Downloader run the command:

```
pip install EToolsbyEndie
```   

## How to Use

**YouTube Video Downloading:**

To download a YouTube video run the command
```download_video``` in command prompt.

**File Type Conversion:**

To convert a file type run the command
```convert_file``` in command prompt.